@@ -11,7 +11,7 @@ use Const::Fast ();
 use Keyword::Simple;
 use Text::Balanced ();
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 sub import {
@@ -42,25 +42,19 @@ sub _rewrite_let {
             $$ref =~ s/^\S+//;
         }
 
-        if ($] >= 5.028 || substr($name, 0, 1) eq '$') {
+        if ($val !~ /[\$\@\%\&]/ && ($] >= 5.028 || substr($name, 0, 1) eq '$')) {
 
             # We can't use Const::Fast on state variables, so we use
             # this workaround.
 
-            $let .= << "HERE"
-use feature 'state';
-state $name = $val;
-unless (state \$set = 0) { Const::Fast::_make_readonly($name); \$set = 1; };
-HERE
+            $let .= "use feature 'state'; state $name = $val; unless (state \$set = 0) { Const::Fast::_make_readonly(\\$name); \$set = 1; };";
 
         }
         else {
 
-            $let .= "Const::Fast::const my $name => $val;\n";
+            $let .= "Const::Fast::const my $name => $val; ";
         }
 
-
-
     } while ( $$ref =~ s/^\s*,\s*// );
 
     my $code;
@@ -93,7 +87,7 @@ PerlX::Let - Syntactic sugar for lexical constants
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
@@ -141,16 +135,18 @@ This is roughly equivalent to using
 
   }
 
-However, if the variable is a scalar, or you are using Perl v5.28 or
-later, this uses state variables so that the value is only set once.
+However, if the value does not contain a sigil, and the variable is a
+scalar, or you are using Perl v5.28 or later, this uses state
+variables so that the value is only set once.
 
 =head1 KNOWN ISSUES
 
-This is an experimental version.
-
 The parsing of assignments is rudimentary, and may fail when assigning
 to another variable or the result of a function.
 
+Because this modifies the source code during compilation, the line
+numebrs may be changed.
+
 =head1 SEE ALSO
 
 L<Const::Fast>
